==> zzyj-outputvalcount-api-3.0.0-20220729.073752-73-sources.jar: com/ejianc/business/outputvalcount/vo/MaterialReportVO.java <==
package com.ejianc.business.outputvalcount.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * MaterialReport
 * 
 * @author generator
 * 
 */
public class MaterialReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgid; // 组织
    private String orgname; // 
    private Long tenantid; // 租户ID
    private Long projectid; // 项目
    private String projectcode; // 项目code
    private String projectname; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ywdate; // 验收日期
    private String parentOrgName; // 
    private Integer ywlx; // 1:临材,2:临工,3:临机
    private String ywlxname; // 
    private Long djid; // 主键ID
    private BigDecimal ataxmny; // 子表验收金额汇总
    

    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }
    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }
    public Long getTenantid() {
        return tenantid;
    }

    public void setTenantid(Long tenantid) {
        this.tenantid = tenantid;
    }
    public Long getProjectid() {
        return projectid;
    }

    public void setProjectid(Long projectid) {
        this.projectid = projectid;
    }
    public String getProjectcode() {
        return projectcode;
    }

    public void setProjectcode(String projectcode) {
        this.projectcode = projectcode;
    }
    public String getProjectname() {
        return projectname;
    }

    public void setProjectname(String projectname) {
        this.projectname = projectname;
    }
    public Date getYwdate() {
        return ywdate;
    }

    public void setYwdate(Date ywdate) {
        this.ywdate = ywdate;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getYwlx() {
        return ywlx;
    }

    public void setYwlx(Integer ywlx) {
        this.ywlx = ywlx;
    }
    public String getYwlxname() {
        return ywlxname;
    }

    public void setYwlxname(String ywlxname) {
        this.ywlxname = ywlxname;
    }
    public Long getDjid() {
        return djid;
    }

    public void setDjid(Long djid) {
        this.djid = djid;
    }
    public BigDecimal getAtaxmny() {
        return ataxmny;
    }

    public void setAtaxmny(BigDecimal ataxmny) {
        this.ataxmny = ataxmny;
    }
    
}

==> zzyj-outputvalcount-api-3.0.0-20250611.235814-373-sources.jar: com/ejianc/business/outputvalcount/vo/MaterialReportVO.java <==
package com.ejianc.business.outputvalcount.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * MaterialReport
 * 
 * @author generator
 * 
 */
public class MaterialReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgid; // 组织
    private String orgname; // 
    private Long tenantid; // 租户ID
    private Long projectid; // 项目
    private String projectcode; // 项目code
    private String projectname; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ywdate; // 验收日期
    private String parentOrgName; // 
    private Integer ywlx; // 1:临材,2:临工,3:临机
    private String ywlxname; // 
    private Long djid; // 主键ID
    private BigDecimal ataxmny; // 子表验收金额汇总
    private Long supid;// 供应商id
    private String supname;// 供应商名称


    public Long getSupid() {
        return supid;
    }

    public void setSupid(Long supid) {
        this.supid = supid;
    }

    public String getSupname() {
        return supname;
    }

    public void setSupname(String supname) {
        this.supname = supname;
    }

    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }
    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }
    public Long getTenantid() {
        return tenantid;
    }

    public void setTenantid(Long tenantid) {
        this.tenantid = tenantid;
    }
    public Long getProjectid() {
        return projectid;
    }

    public void setProjectid(Long projectid) {
        this.projectid = projectid;
    }
    public String getProjectcode() {
        return projectcode;
    }

    public void setProjectcode(String projectcode) {
        this.projectcode = projectcode;
    }
    public String getProjectname() {
        return projectname;
    }

    public void setProjectname(String projectname) {
        this.projectname = projectname;
    }
    public Date getYwdate() {
        return ywdate;
    }

    public void setYwdate(Date ywdate) {
        this.ywdate = ywdate;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getYwlx() {
        return ywlx;
    }

    public void setYwlx(Integer ywlx) {
        this.ywlx = ywlx;
    }
    public String getYwlxname() {
        return ywlxname;
    }

    public void setYwlxname(String ywlxname) {
        this.ywlxname = ywlxname;
    }
    public Long getDjid() {
        return djid;
    }

    public void setDjid(Long djid) {
        this.djid = djid;
    }
    public BigDecimal getAtaxmny() {
        return ataxmny;
    }

    public void setAtaxmny(BigDecimal ataxmny) {
        this.ataxmny = ataxmny;
    }
    
}
